| zuyaml_map | R Documentation |
YAML mapping keys can be sequences or mappings, which cannot become R names
without destroying structure. yaml_parse() represents such a mapping as a
zuyaml_map: two parallel lists, keys and values.
## S3 method for class 'zuyaml_map'
print(x, ...)
x |
A |
... |
Ignored. |
This is parse-only. The vendored cyaml builder can only attach string keys,
so a zuyaml_map cannot be emitted; see vignette("zuyaml") for the full
list of conversions that do not round-trip.
print() returns x invisibly.
yaml_parse("? [one, two]\n: value\n")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.